Page Explorer
=============
[![Task Status](https://community-tc.services.mozilla.com/api/github/v1/repository/MozillaSecurity/page-explorer/main/badge.svg)](https://community-tc.services.mozilla.com/api/github/v1/repository/MozillaSecurity/page-explorer/main/latest)
[![codecov](https://codecov.io/gh/MozillaSecurity/page-explorer/branch/main/graph/badge.svg)](https://codecov.io/gh/MozillaSecurity/page-explorer)
[![Matrix](https://img.shields.io/badge/chat-%23fuzzing-green?logo=matrix)](https://matrix.to/#/#fuzzing:mozilla.org)
[![PyPI](https://img.shields.io/pypi/v/page-explorer)](https://pypi.org/project/page-explorer)

Page Explorer facilitates content interactions via instructions.

See [Site-Scout](/MozillaSecurity/site-scout) to see it in action.
